==> tabulator-1.7.0.tar.gz: tabulator-1.7.0/tabulator/parsers/ods.py <==
# -*- coding: utf-8 -*-
from __future__ import division
from __future__ import print_function
from __future__ import absolute_import
from __future__ import unicode_literals

import ezodf
from six import BytesIO
from ..parser import Parser
from .. import helpers


# Module API

class ODSParser(Parser):
    """Parser to parse ODF Spreadsheets.

    Args:
        sheet (int or str): sheet number or name
            First sheet's number is 1.

    """

    # Public

    options = [
        'sheet',
    ]

    def __init__(self, loader, force_parse=False, sheet=1):
        self.__loader = loader
        self.__index = sheet - 1 if isinstance(sheet, int) else sheet
        self.__force_parse = force_parse
        self.__extended_rows = None
        self.__encoding = None
        self.__bytes = None
        self.__book = None
        self.__sheet = None

    @property
    def closed(self):
        return self.__bytes is None or self.__bytes.closed

    def open(self, source, encoding=None):
        self.close()
        self.__bytes = self.__loader.load(
            source, mode='b', encoding=encoding, allow_zip=True)
        self.__book = ezodf.opendoc(BytesIO(self.__bytes.read()))
        self.__sheet = self.__book.sheets[self.__index]
        self.__encoding = encoding
        self.reset()

    def close(self):
        if not self.closed:
            self.__bytes.close()

    def reset(self):
        helpers.reset_stream(self.__bytes)
        self.__extended_rows = self.__iter_extended_rows()

    @property
    def encoding(self):
        return self.__encoding

    @property
    def extended_rows(self):
        return self.__extended_rows

    # Private

    def __iter_extended_rows(self):
        for row_number, row in enumerate(self.__sheet.rows(), start=1):
            yield row_number, None, [cell.value for cell in row]

==> tabulator-1.11.1.tar.gz: tabulator-1.11.1/tabulator/parsers/ods.py <==
# -*- coding: utf-8 -*-
from __future__ import division
from __future__ import print_function
from __future__ import absolute_import
from __future__ import unicode_literals

import six
import ezodf
from six import BytesIO
from ..parser import Parser
from .. import exceptions
from .. import helpers


# Module API

class ODSParser(Parser):
    """Parser to parse ODF Spreadsheets.
    """

    # Public

    options = [
        'sheet',
    ]

    def __init__(self, loader, force_parse=False, sheet=1):
        self.__loader = loader
        self.__sheet_pointer = sheet
        self.__force_parse = force_parse
        self.__extended_rows = None
        self.__encoding = None
        self.__bytes = None
        self.__book = None
        self.__sheet = None

    @property
    def closed(self):
        return self.__bytes is None or self.__bytes.closed

    def open(self, source, encoding=None):
        self.close()
        self.__encoding = encoding
        self.__bytes = self.__loader.load(source, mode='b', encoding=encoding)

        # Get book
        self.__book = ezodf.opendoc(BytesIO(self.__bytes.read()))

        # Get sheet
        try:
            if isinstance(self.__sheet_pointer, six.string_types):
                self.__sheet = self.__book.sheets[self.__sheet_pointer]
            else:
                self.__sheet = self.__book.sheets[self.__sheet_pointer - 1]
        except (KeyError, IndexError):
            message = 'OpenOffice document "%s" doesn\'t have a sheet "%s"'
            raise exceptions.SourceError(message % (source, self.__sheet_pointer))

        # Rest parser
        self.reset()

    def close(self):
        if not self.closed:
            self.__bytes.close()

    def reset(self):
        helpers.reset_stream(self.__bytes)
        self.__extended_rows = self.__iter_extended_rows()

    @property
    def encoding(self):
        return self.__encoding

    @property
    def extended_rows(self):
        return self.__extended_rows

    # Private

    def __iter_extended_rows(self):
        for row_number, row in enumerate(self.__sheet.rows(), start=1):
            yield row_number, None, [cell.value for cell in row]
